@@ -107,6 +107,7 @@ typedef struct
     gboolean             have_set_arch;
     gboolean             all_arch;
     gboolean             provides_ready;
+    gboolean             allow_vendor_change;
     gchar               *cache_dir;
     char                *arch;
     dnf_sack_running_kernel_fn_t  running_kernel_fn;
@@ -189,6 +190,7 @@ dnf_sack_init(DnfSack *sack)
     priv->running_kernel_fn = running_kernel;
     priv->considered_uptodate = TRUE;
     priv->cmdline_repo = NULL;
+    priv->allow_vendor_change = TRUE;
     queue_init(&priv->installonly);
 
     /* logging up after this*/
@@ -843,6 +845,46 @@ dnf_sack_get_all_arch (DnfSack *sack)
     return priv->all_arch;
 }
 
+/*
+ * dnf_sack_set_allow_vendor_change:
+ * @sack: a #DnfSack instance.
+ * @allow_vendor_change is a boolean.
+ *
+ * Sets the value of allow vendor change to use for
+ * SOLVER_FLAG_ALLOW_VENDORCHANGE flag
+ *
+ * Returns: Nothing.
+ *
+ * Since: 0.54.3
+ *
+ * */
+void
+dnf_sack_set_allow_vendor_change(DnfSack *sack, gboolean allow_vendor_change)
+{
+    DnfSackPrivate *priv = GET_PRIVATE(sack);
+    priv->allow_vendor_change = allow_vendor_change;
+}
+
+/*
+ * dnf_sack_get_allow_vendor_change:
+ * @sack: a #DnfSack instance.
+ * @allow_vendor_change is a boolean.
+ *
+ * Gets the value of allow vendor change to use for
+ * SOLVER_FLAG_ALLOW_VENDORCHANGE flag
+ *
+ * Returns: True if flag set to 1, False if set to 0
+ *
+ * Since: 0.54.3
+ *
+ * */
+gboolean
+dnf_sack_get_allow_vendor_change(DnfSack *sack)
+{
+    DnfSackPrivate *priv = GET_PRIVATE(sack);
+    return priv->allow_vendor_change;
+}
+
 /**
  * dnf_sack_get_arch
  * @sack: a #DnfSack instance.
@@ -2293,20 +2335,29 @@ setModuleExcludes(DnfSack *sack, const char ** hotfixRepos,
 {
     dnf_sack_set_module_excludes(sack, nullptr);
     std::vector<std::string> names;
+    std::vector<std::string> srcNames;
     libdnf::DependencyContainer nameDependencies{sack};
     libdnf::Nevra nevra;
     for (const auto &rpm : includeNEVRAs) {
         if (nevra.parse(rpm.c_str(), HY_FORM_NEVRA)) {
-            names.push_back(nevra.getName());
-            nameDependencies.addReldep(nevra.getName().c_str());
+            auto arch = nevra.getArch();
+            // source packages do not provide anything and must not cause excluding binary packages
+            if (arch == "src" || arch == "nosrc") {
+                srcNames.push_back(nevra.getName());
+            } else {
+                names.push_back(nevra.getName());
+                nameDependencies.addReldep(nevra.getName().c_str());
+            }
         }
     }
 
     std::vector<const char *> namesCString(names.size() + 1);
+    std::vector<const char *> srcNamesCString(srcNames.size() + 1);
     std::vector<const char *> excludeNEVRAsCString(excludeNEVRAs.size() + 1);
     std::vector<const char *> includeNEVRAsCString(includeNEVRAs.size() + 1);
 
     transform(names.begin(), names.end(), namesCString.begin(), std::mem_fn(&std::string::c_str));
+    transform(srcNames.begin(), srcNames.end(), srcNamesCString.begin(), std::mem_fn(&std::string::c_str));
     transform(excludeNEVRAs.begin(), excludeNEVRAs.end(), excludeNEVRAsCString.begin(),
               std::mem_fn(&std::string::c_str));
     transform(includeNEVRAs.begin(), includeNEVRAs.end(), includeNEVRAsCString.begin(),
@@ -2321,6 +2372,7 @@ setModuleExcludes(DnfSack *sack, const char ** hotfixRepos,
     libdnf::Query excludeQuery{keepPackages};
     libdnf::Query excludeProvidesQuery{keepPackages};
     libdnf::Query excludeNamesQuery(keepPackages);
+    libdnf::Query excludeSrcNamesQuery(keepPackages);
     includeQuery.addFilter(HY_PKG_NEVRA_STRICT, HY_EQ, includeNEVRAsCString.data());
 
     excludeQuery.addFilter(HY_PKG_NEVRA_STRICT, HY_EQ, excludeNEVRAsCString.data());
@@ -2330,8 +2382,14 @@ setModuleExcludes(DnfSack *sack, const char ** hotfixRepos,
     excludeProvidesQuery.addFilter(HY_PKG_PROVIDES, &nameDependencies);
     excludeProvidesQuery.queryDifference(includeQuery);
 
-    // Requred to filtrate out source packages and packages with incompatible architectures
+    // Search for source packages with same names as included source artifacts
+    excludeSrcNamesQuery.addFilter(HY_PKG_NAME, HY_EQ, srcNamesCString.data());
+    const char * srcArchs[] = {"src", "nosrc", nullptr};
+    excludeSrcNamesQuery.addFilter(HY_PKG_ARCH, HY_EQ, srcArchs);
+
+    // Required to filtrate out source packages and packages with incompatible architectures
     excludeNamesQuery.addFilter(HY_PKG_NAME, HY_EQ, namesCString.data());
+    excludeNamesQuery.queryUnion(excludeSrcNamesQuery);
     excludeNamesQuery.queryDifference(includeQuery);
 
     dnf_sack_set_module_excludes(sack, excludeQuery.getResultPset());
@@ -2421,7 +2479,7 @@ std::string dnf_sack_get_rpmdb_version(DnfSack *sack) {
 
     // iterate all @System repo RPMs (rpmdb records)
     libdnf::Query query{sack, libdnf::Query::ExcludeFlags::IGNORE_EXCLUDES};
-    query.addFilter(HY_PKG_REPONAME, HY_EQ, HY_SYSTEM_REPO_NAME);
+    query.installed();
 
     auto pset = query.getResultPset();
     Id id = -1;
