@@ -607,7 +607,8 @@ ModulePackageContainer::Impl::moduleSolve(const std::vector<ModulePackage *> & m
 {
     if (modules.empty()) {
         activatedModules.reset();
-        return {};
+        return std::make_pair(std::vector<std::vector<std::string>>(),
+                              ModulePackageContainer::ModuleErrorType::NO_ERROR);
     }
     dnf_sack_recompute_considered(moduleSack);
     dnf_sack_make_provides_ready(moduleSack);
@@ -671,7 +672,7 @@ ModulePackageContainer::query(std::string subject)
     std::vector<ModulePackage *> result;
     Query query(pImpl->moduleSack, Query::ExcludeFlags::IGNORE_EXCLUDES);
     // platform modules are installed and not in modules std::Map.
-    query.addFilter(HY_PKG_REPONAME, HY_NEQ, HY_SYSTEM_REPO_NAME);
+    query.available();
     std::ostringstream ss;
     ss << subject << "*";
     query.addFilter(HY_PKG_NAME, HY_GLOB, ss.str().c_str());
@@ -691,7 +692,7 @@ ModulePackageContainer::query(std::string name, std::string stream, std::string
     std::vector<ModulePackage *> result;
     Query query(pImpl->moduleSack, Query::ExcludeFlags::IGNORE_EXCLUDES);
     // platform modules are installed and not in modules std::Map.
-    query.addFilter(HY_PKG_REPONAME, HY_NEQ, HY_SYSTEM_REPO_NAME);
+    query.available();
     std::ostringstream ss;
     ss << stringFormater(name) << ":" << stringFormater(stream);
     ss << ":" << stringFormater(version) << ":";
@@ -822,9 +823,40 @@ std::string
 ModulePackageContainer::getReport()
 {
     std::string report;
+
+    auto installedProfiles = getInstalledProfiles();
+    if (!installedProfiles.empty()) {
+        report += _("Installing module profiles:\n");
+        for (auto & item: installedProfiles) {
+            for (auto & profile:item.second) {
+                report += "    ";
+                report += item.first;
+                report += ":";
+                report += profile;
+                report += "\n";
+            }
+        }
+        report += "\n";
+    }
+
+    auto removedProfiles = getRemovedProfiles();
+    if (!removedProfiles.empty()) {
+        report += _("Disabling module profiles:\n");
+        for (auto & item: removedProfiles) {
+            for (auto & profile:item.second) {
+                report += "    ";
+                report += item.first;
+                report += ":";
+                report += profile;
+                report += "\n";
+            }
+        }
+        report += "\n";
+    }
+
     auto enabled = getEnabledStreams();
     if (!enabled.empty()) {
-        report += "Module Enabling:\n";
+        report += _("Enabling module streams:\n");
         for (auto & item: enabled) {
             report += "    ";
             report += item.first;
@@ -834,20 +866,11 @@ ModulePackageContainer::getReport()
         }
         report += "\n";
     }
-    auto disabled = getDisabledModules();
-    if (!disabled.empty()) {
-        report += "Module Disabling:\n";
-        for (auto & name: disabled) {
-            report += "    ";
-            report += name;
-            report += "\n";
-        }
-        report += "\n";
-    }
+
     auto switchedStreams = getSwitchedStreams();
     if (!switchedStreams.empty()) {
         std::string switchedReport;
-        switchedReport += "Module Switched Streams:\n";
+        switchedReport += _("Switching module streams:\n");
         for (auto & item: switchedStreams) {
             switchedReport += "    ";
             switchedReport += item.first;
@@ -862,31 +885,25 @@ ModulePackageContainer::getReport()
         report += switchedReport;
         report += "\n";
     }
-    auto installedProfiles = getInstalledProfiles();
-    if (!installedProfiles.empty()) {
-        report += "Module Installing Profiles:\n";
-        for (auto & item: installedProfiles) {
-            for (auto & profile:item.second) {
-                report += "    ";
-                report += item.first;
-                report += ":";
-                report += profile;
-                report += "\n";
-            }
+
+    auto disabled = getDisabledModules();
+    if (!disabled.empty()) {
+        report += _("Disabling modules:\n");
+        for (auto & name: disabled) {
+            report += "    ";
+            report += name;
+            report += "\n";
         }
         report += "\n";
     }
-    auto removedProfiles = getRemovedProfiles();
-    if (!removedProfiles.empty()) {
-        report += "Module Removing Profiles:\n";
-        for (auto & item: removedProfiles) {
-            for (auto & profile:item.second) {
-                report += "    ";
-                report += item.first;
-                report += ":";
-                report += profile;
-                report += "\n";
-            }
+
+    auto reset = getResetModules();
+    if (!reset.empty()) {
+        report += _("Resetting modules:\n");
+        for (auto & name: reset) {
+            report += "    ";
+            report += name;
+            report += "\n";
         }
         report += "\n";
     }
